====================
python-derivermodule
====================

This python library should make it easier to write deriver modules for the
Internet Archive processing cluster.

See the readthedocs page for the latest documentation:

    https://archive-derivermodule.readthedocs.io/en/latest/
